==> libsfml_2.3.2+dfsg.orig.tar.xz: SFML-2.3.2/src/SFML/System/Unix/ThreadLocalImpl.cpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2015 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/System/Unix/ThreadLocalImpl.hpp>


namespace sf
{
namespace priv
{
////////////////////////////////////////////////////////////
ThreadLocalImpl::ThreadLocalImpl()
{
    pthread_key_create(&m_key, NULL);
}


////////////////////////////////////////////////////////////
ThreadLocalImpl::~ThreadLocalImpl()
{
    pthread_key_delete(m_key);
}


////////////////////////////////////////////////////////////
void ThreadLocalImpl::setValue(void* value)
{
    pthread_setspecific(m_key, value);
}


////////////////////////////////////////////////////////////
void* ThreadLocalImpl::getValue() const
{
    return pthread_getspecific(m_key);
}

} // namespace priv

} // namespace sf

==> libsfml_2.4.1+dfsg.orig.tar.xz: SFML-2.4.1/src/SFML/System/Unix/ThreadLocalImpl.cpp <==
////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2016 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/System/Unix/ThreadLocalImpl.hpp>


namespace sf
{
namespace priv
{
////////////////////////////////////////////////////////////
ThreadLocalImpl::ThreadLocalImpl() :
m_key(0)
{
    pthread_key_create(&m_key, NULL);
}


////////////////////////////////////////////////////////////
ThreadLocalImpl::~ThreadLocalImpl()
{
    pthread_key_delete(m_key);
}


////////////////////////////////////////////////////////////
void ThreadLocalImpl::setValue(void* value)
{
    pthread_setspecific(m_key, value);
}


////////////////////////////////////////////////////////////
void* ThreadLocalImpl::getValue() const
{
    return pthread_getspecific(m_key);
}

} // namespace priv

} // namespace sf
